@@ -1,76 +1,87 @@
 /*
-  globals.h
+   globals.h:
 
-  For TuxMath
+   Contains global data for configuration of math questions and for
+   general game options, as well as constants and defaults.  Nothing
+   depending on SDL should be in here; put any SDL-related items into
+   tuxmath.h.
 
-  Contains global data for configuration of math questions and for
-  general game options, as well as constants and defaults.  Nothing
-  depending on SDL should be in here; put any SDL-related items into
-  tuxmath.h.
+   Copyright 2006, 2007, 2008, 2009, 2010.
+Authors: David Bruce, Tim Holy, and others.
+Project email: <tuxmath-devel@lists.sourceforge.net>
+Project website: http://tux4kids.alioth.debian.org
 
-  Author: David Bruce <davidstuartbruce@gmail.com>, (C) 2006
+game.h is part of "Tux, of Math Command", a.k.a. "tuxmath".
 
+Tuxmath is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
 
-  Part of "Tux4Kids" Project
-  http://www.tux4kids.org/
+Tuxmath is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-  Added March 2, 2006
-
-  Copyright: See COPYING file that comes with this distribution
-  (briefly - GNU GPL v2 or later)
-*/
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 
 
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
-//#include "config.h"
-#include "config.h"
-
 // Translation stuff (now works for Mac and Win too!): 
+#include "config.h"
 #include "gettext.h"
 #include <locale.h>
 #define _(String) gettext (String)
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
 
+#ifdef WIN32
+#define TUXLOCALE "./locale"
+#else
+#define TUXLOCALE LOCALEDIR
+#endif
+
 #include <wchar.h>
 
-typedef enum { false, true } bool;
+#include <t4k_common.h>
+/* Conditional includes of t4k_common replacement functions
+ * if not supplied by platform:
+ */
+/* Somehow, configure defines HAVE_ALPHASORT and
+ * HAVE_SCANDIR for mingw32 even though they are 
+ * not available for that build, so use our own:
+ */
+#if !defined HAVE_ALPHASORT || defined BUILD_MINGW32
+#include <t4k_alphasort.h>
+#endif
+#if !defined HAVE_SCANDIR || defined BUILD_MINGW32
+#include <t4k_scandir.h>
+#endif
 
-#define min(a,b) (((a) < (b)) ? (a) : (b))
-#define max(a,b) (((a) > (b)) ? (a) : (b))
-
-/* for Tim's feedback speed control code           */
-//#define FEEDBACK_DEBUG
-//#define LINEBREAK
-
-/* debug data (declared in options.c) */
-extern int debug_status;
+/* debug data (now declared in libt4k_common */
+//extern int debug_status;
 
 /* bitmasks for debugging options (declared in options.c) */
 extern const int debug_setup;
 extern const int debug_fileops;
-extern const int debug_loaders;
 extern const int debug_titlescreen;
-extern const int debug_menu;
-extern const int debug_menu_parser;
 extern const int debug_game;
 extern const int debug_factoroids;
 extern const int debug_lan;
 extern const int debug_mathcards;
-extern const int debug_sdl;
 extern const int debug_lessons;
 extern const int debug_highscore;
 extern const int debug_options;
-extern const int debug_convert_utf;
+extern const int debug_text_and_intl;
 extern const int debug_multiplayer;
-extern const int debug_all;
 
-/* debug macros */
-#define DEBUGCODE(mask) if((mask) & debug_status)
-#define DEBUGMSG(mask, ...) if((mask) & debug_status){ fprintf(stderr, __VA_ARGS__); fflush(stderr); }
+/* debug macros (now in libt4k_comon) */
+//#define DEBUGCODE(mask) if((mask) & debug_status)
+//#define DEBUGMSG(mask, ...) if((mask) & debug_status){ fprintf(stderr, __VA_ARGS__); fflush(stderr); }
 
 /* Maximum length of file path: */
 #define PATH_MAX 4096
@@ -102,6 +113,8 @@ extern const int debug_all;
 #define DEFAULT_STARTING_COMETS 2
 #define DEFAULT_EXTRA_COMETS_PER_WAVE 2
 #define DEFAULT_MAX_COMETS 10
+#define DEFAULT_USE_POWERUP_COMETS 1
+#define DEFAULT_POWERUP_FREQ 10
 #define DEFAULT_SAVE_SUMMARY 1        
 #define DEFAULT_SOUND_HW_AVAILABLE 1
 #define DEFAULT_USE_IGLOOS 1
@@ -126,12 +139,13 @@ extern const int debug_all;
 #define MAX_MAX_COMETS 100
 #define SCORE_COEFFICIENT 100
 
+#define LESSON_TITLE_LENGTH 256
+#define DEFAULT_LESSON_TITLE "DEFAULT LESSON TITLE"
 #define DEFAULT_FONT_NAME "AndikaDesRevG.ttf"
 #define FONT_NAME_LENGTH 64
 #define DEFAULT_MENU_FONT_SIZE 18
 #define DEFAULT_HELP_FONT_SIZE 32
 
-
 #define HIGH_SCORES_SAVED 10
 #define HIGH_SCORE_NAME_LENGTH 32
 
@@ -141,18 +155,18 @@ extern const int debug_all;
 #define PIXEL_BITS 32
 
 enum {
-  CADET_HIGH_SCORE,
-  SCOUT_HIGH_SCORE,
-  RANGER_HIGH_SCORE,
-  ACE_HIGH_SCORE,
-  COMMANDO_HIGH_SCORE,
-  NUM_MATH_COMMAND_LEVELS
+    CADET_HIGH_SCORE,
+    SCOUT_HIGH_SCORE,
+    RANGER_HIGH_SCORE,
+    ACE_HIGH_SCORE,
+    COMMANDO_HIGH_SCORE,
+    NUM_MATH_COMMAND_LEVELS
 };
 
 enum {
-  FACTORS_HIGH_SCORE = NUM_MATH_COMMAND_LEVELS,
-  FRACTIONS_HIGH_SCORE,
-  NUM_HIGH_SCORE_LEVELS
+    FACTORS_HIGH_SCORE = NUM_MATH_COMMAND_LEVELS,
+    FRACTIONS_HIGH_SCORE,
+    NUM_HIGH_SCORE_LEVELS
 };
 
 
