@@ -1,28 +1,40 @@
 /*
-  tuxmath.h
+   tuxmath.h:
 
-  For TuxMath
-  Contains global data for configuration of math questions and
-  for general game options, as well as constants and defaults.
+   Contains global data for configuration of math questions and
+   for general game options, as well as constants and defaults.
 
-  Author: David Bruce <davidstuartbruce@gmail.com>, (C) 2006
+   Copyright 2005, 2007, 2008, 2009, 2010.
+Authors: David Bruce, Tim Holy
+Project email: <tuxmath-devel@lists.sourceforge.net>
+Project website: http://tux4kids.alioth.debian.org
 
 
-  Part of "Tux4Kids" Project
-  http://www.tux4kids.org/
-      
-  Added March 2, 2006
+tuxmath.h is part of "Tux, of Math Command", a.k.a. "tuxmath".
+
+Tuxmath is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+Tuxmath is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-  Copyright: See COPYING file that comes with this distribution
-  (briefly - GNU GPL v2 or later)
 */
 
 
 
+
 #ifndef TUXMATH_H
 #define TUXMATH_H
 
 #include "globals.h"
+#include "compiler.h"
 
 #include "SDL.h"
 #include "SDL_image.h"
@@ -32,14 +44,7 @@
 #endif
 
 
-#define MAX_SPRITE_FRAMES   30
-
-typedef struct {
-  SDL_Surface *frame[MAX_SPRITE_FRAMES];
-  SDL_Surface *default_img;
-  int num_frames;
-  int cur;
-} sprite;
+#include <t4k_common.h>
 
 /* Global data gets 'externed' here: */
 
@@ -58,6 +63,7 @@ extern SDL_Color dark_blue;
 extern SDL_Color red;
 extern SDL_Color white;
 extern SDL_Color yellow;
+extern SDL_Color bright_green;
 
 extern SDL_Surface* screen; /* declared in setup.c; also used in game.c, options.c, fileops.c, credits.c, titlescreen.c */
 extern SDL_Surface* images[];    /* declared in setup.c, used in same files as screen */
